@@ -37,13 +37,15 @@ class UserManager(BaseUserManager):
         try:
             user = self.model.objects.get(email=email, is_guest=True)
 
-            self.model.objects.filter(id=user.id).update(
-              is_staff=is_staff,
-              is_active=True,
-              is_superuser=is_superuser,
-              is_guest=is_guest,
-              date_joined=now,
-              is_email_verified=False, **extra_fields)
+            user.is_staff = is_staff
+            user.is_active = True
+            user.is_superuser = is_superuser
+            user.is_guest = is_guest
+            user.date_joined = now
+            user.is_email_verified = False
+
+            for key in extra_fields:
+                setattr(user, key, extra_fields[key])
 
         except self.model.DoesNotExist:
             user = self.model(email=email,
